---
title: burusftp user key add
linkTitle: user key add
---

## NAME
`burusftp user key add` - Add user's public key

## SYNOPSIS
```fish
burusftp user key add -u <username> -f (<key_path> | -) [-c <comment>]
burusftp user key add -u <username> -i <key> [-c <comment>]
```

## DESCRIPTION
Read SSH public key and assign it to user specified. 

Enable or enforce public key authentication by calling 

```fish
burusftp user update -u <username> --key-auth (required | enabled)
```   

## OPTIONS
* `-c, --comment <comment>`
  * Comment for the imported key 
* `-f, --file (<key_path> | -)`
  * Read key from file or from standard input when `-` is used. SSH2, PKCS#8, authorized_keys and base-64 encoded keys are supported.
* `-i, --key <key>`
  * Base-64 encoded public key passed directly as argument
* `-u, --username <username>`
  * Username (required).
* `--help`
  * Display this help.


## EXAMPLES
```fish
# Read RSA public key from file and assign it to user 'elaine'
burusftp user key add -u elaine -f "C:\rsa.pub"

# Read public key from standard input and assign it to user 'elaine' with custom comment
burusftp user key add -u elaine -c "elaine's key" -f -

# Assign Ed25519 public key to user 'elaine'
burusftp user key add -u elaine -i "AAAAC3NzaC1lZDI1NTE5AAAAIAo5oLWzlyMr0T4jY/hZyagW04FzHCyRdSwXkeM8/u87"
```

## SEE ALSO
[user key delete]({{< ref "user-key-delete" >}}), [user update]({{< ref "user-update" >}})